# Overview

This package is meant to be run as a job on a Databricks cluster.  It performs high-speed data export to the specified blob storage location.

The job's package_name should `databricks_stage` and the entry_point should be `run`.
